@@ -1,4 +1,4 @@
-# Copyright 2018-2023 contributors to the OpenLineage project
+# Copyright 2018-2024 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 """
 To implement custom Transport implement Config and Transport classes.
@@ -37,7 +37,7 @@ class Transport:
     kind: str | None = None
     config_class: type[Config] = Config
 
-    def emit(self, event: Union[RunEvent, DatasetEvent, JobEvent]) -> Any:  # noqa: ANN401, UP007
+    def emit(self, event: Union[RunEvent, DatasetEvent, JobEvent]) -> Any:  # noqa: UP007
         raise NotImplementedError
 
 
